@@ -618,7 +618,7 @@ function(x, i, j, drop = FALSE)
 		return(vector(mode = typeof(x$v), length = 0L))
 	    ## Ignore dimensions
 	    if(ncol(i) != 2L || !is.numeric(i))
-		return(do.call("[.simple_triplet_matrix",
+		return(do.call(`[.simple_triplet_matrix`,
 			       list(x = x, as.vector(i))))
 
 	    if(is.double(i))
@@ -778,7 +778,7 @@ function(..., deparse.level = 1L)
     }, args)
     ## Handle dimnames in one final step.
     rnms <- lapply(args, rownames)
-    rnms <- if(!all(sapply(rnms, is.null))) {
+    rnms <- if(!all(vapply(rnms, is.null, NA))) {
 	rnms <- mapply(function(rnm, n)
 	    if(is.null(rnm))
 		rep.int("", n)
@@ -789,7 +789,7 @@ function(..., deparse.level = 1L)
 	    SIMPLIFY = FALSE
 	)
 	
-        do.call("c", rnms)
+        do.call(c, rnms)
     }
     else
         NULL
@@ -815,7 +815,7 @@ function(..., deparse.level = 1L)
     }, args)
     ## Handle dimnames in one final step.
     cnms <- lapply(args, colnames)
-    cnms <- if(!all(sapply(cnms, is.null))) {
+    cnms <- if(!all(vapply(cnms, is.null, NA))) {
 	cnms <- mapply(function(cnm, n)
 	    if(is.null(cnm))
 		rep.int("", n)
@@ -825,7 +825,7 @@ function(..., deparse.level = 1L)
 	    lapply(args, ncol),
 	    SIMPLIFY = FALSE
 	)
-        do.call("c", cnms)
+        do.call(c, cnms)
     }
     else
         NULL
@@ -859,7 +859,7 @@ function(x, incomparables = FALSE, MARGIN = 1L, fromLast = FALSE, ...)
     y <- split(paste(j[o], x$v[o], sep = "\r"), i[o])
     tmp <- character(len)
     names(tmp) <- seq_along(tmp)
-    tmp[names(y)] <- sapply(y, paste, collapse = "\r")
+    tmp[names(y)] <- vapply(y, paste, "", collapse = "\r")
     duplicated(tmp, fromLast = fromLast)
 }
 
@@ -879,7 +879,7 @@ c.simple_triplet_matrix <-
 function(..., recursive = FALSE)
 {
     args <- list(...)
-    ind <- which(sapply(args, inherits, "simple_triplet_matrix"))
+    ind <- which(vapply(args, inherits, NA, "simple_triplet_matrix"))
     args[ind] <-
         lapply(args[ind],
                function(x) {
@@ -887,7 +887,7 @@ function(..., recursive = FALSE)
                    y[x$i + (x$j - 1L) * x$nrow] <- x$v
                    y
                })
-    do.call("c", args)
+    do.call(c, args)
 }
 
 print.simple_triplet_matrix <-
