@@ -20,23 +20,22 @@ function(x, strict = FALSE, order = FALSE)
     V <- .Call(R_unattr, x$v)
     if (length(V)) {
 	## reduce multiple entries
-	i <- .Call(R_match_matrix, I)
+	i <- .Call(R_match_matrix, I, NULL, NULL)
 	if (length(i[[1L]]) > length(i[[2L]])) {
 	    if (strict)
 		stop("multiple entries")
 	    I <- I[i[[2L]],, drop = FALSE]
-	    i <- structure(
-		i[[1L]],
-		levels = seq_len(dim(I)[1L]),
-		class  = "factor"
-	    )
+	    i <- i[[1L]]
+	    attributes(i) <-
+		list(levels = seq_len(dim(I)[1L]), 
+		     class  = "factor")
 	    V <- split(V, i)
 	    rm(i)
 	    names(V) <- NULL
 	    V <- sapply(V, function(x) 
 		if (length(x) > 1L) {
 		    x <- as.list(x)
-		    if (all(sapply(x[-1L], identical, x[[1L]])))
+		    if (all(vapply(x[-1L], identical, NA, x[[1L]])))
 			x[[1L]]
 		    else
 			NA
@@ -58,7 +57,7 @@ function(x, strict = FALSE, order = FALSE)
 	rm(i)
 	## order entries
 	if (order) {
-	    i <- do.call("order", rev(.Call(R_split_col, I)))
+	    i <- do.call(base::order, rev(.Call(R_split_col, I)))
 	    if (!identical(i, seq_along(i))) {
 		V <- V[i]
 		I <- I[i,, drop = FALSE]
@@ -71,7 +70,7 @@ function(x, strict = FALSE, order = FALSE)
     N <-
     if (!length(N) ||
 	(is.null(names(N)) &&
-	  all(sapply(N, is.null))))
+	  all(vapply(N, is.null, NA))))
 	NULL
     else
 	lapply(N, as.vector)
@@ -138,7 +137,7 @@ function(x, higher = TRUE)
 	l <- dim(I)[1L]
 	if (k > 1L)
 	    I <- apply(I, 2L, rep, each = k)
-	I <- cbind(rep(seq.int(k), l), I)
+	I <- cbind(rep.int(seq.int(k), l), I)
     }
     if (!is.null(N)) {
 	if (!is.list(n))
